==> _private_core_network-1.2.25.tar.gz: lib/network_resources/platform/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

import '../common/models/file_upload_result.dart';
import 'models/platform_status_chat.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getStatusChatList() => "v2/platform/getStatusChatList";
  static String getMyCurrentStatusChatForPlatformId() =>
      "v2/platform/getMyCurrentStatusChatForPlatformId";
  static String getStatusChatForPlatformIdByUsername() =>
      "v2/platform/getStatusChatForPlatformIdByUsername";
  static String updateStatusChatForPlatformId() =>
      "v2/platform/updateStatusChatForPlatformId";
  static String createChatGroup() => "v2/platform/createChatGroup";
  static String setThumbnailForChatGroup() =>
      "v2/platform/setThumbnailForChatGroup";
}

abstract class MyAppApi {
  Future<NetworkResponse> getStatusChatList(params);
  Future<NetworkResponse> getMyCurrentStatusChatForPlatformId(params);
  Future<NetworkResponse> getStatusChatForPlatformIdByUsername(params);
  Future<NetworkResponse> updateStatusChatForPlatformId(params);
  Future<NetworkResponse> createChatGroup(params);
  Future<NetworkResponse> setThumbnailForChatGroup(groupId, bytes, filePath);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getStatusChatList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(_MyAppEndpoint.getStatusChatList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PlatformStatusChat.fromJson(e)).toList(),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMyCurrentStatusChatForPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getMyCurrentStatusChatForPlatformId(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformStatusChat.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getStatusChatForPlatformIdByUsername(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getStatusChatForPlatformIdByUsername(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformStatusChat.fromJson(json),
      );
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateStatusChatForPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(_MyAppEndpoint.updateStatusChatForPlatformId(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createChatGroup(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(_MyAppEndpoint.createChatGroup(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioError catch (e) {
      appDebugPrint('DioError: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForChatGroup(
      groupId, bytes, filePath) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
        "groupId": groupId,
      });
      final token = await appPrefs.getNormalToken();
      Response response = await AppClient(requiredToken: true, token: token)
          .post(_MyAppEndpoint.setThumbnailForChatGroup(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => FileUploadResult.fromJson(json));
    } on DioError catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}

==> _private_core_network-1.2.54.tar.gz: lib/network_resources/platform/app_api.dart <==
import 'package:_private_core/_private_core.dart';
import 'package:_private_core_network/network_resources/resources.dart';
import 'package:dio/dio.dart';

import '../common/models/file_upload_result.dart';
import 'models/platform_status_chat.dart';

class _MyAppEndpoint {
  _MyAppEndpoint._();
  static String getStatusChatList() => "v2/platform/getStatusChatList";
  static String getMyCurrentStatusChatForPlatformId() =>
      "v2/platform/getMyCurrentStatusChatForPlatformId";
  static String getStatusChatForPlatformId() =>
      "v2/platform/getStatusChatForPlatformId";
  static String updateStatusChatForPlatformId() =>
      "v2/platform/updateStatusChatForPlatformId";
  static String createChatGroup() => "v2/platform/createChatGroup";
  static String setThumbnailForChatGroup() =>
      "v2/platform/setThumbnailForChatGroup";
}

abstract class MyAppApi {
  Future<NetworkResponse> getStatusChatList(params);
  Future<NetworkResponse> getMyCurrentStatusChatForPlatformId(params);
  Future<NetworkResponse> getStatusChatForPlatformId(params);
  Future<NetworkResponse> updateStatusChatForPlatformId(params);
  Future<NetworkResponse> createChatGroup(params);
  Future<NetworkResponse> setThumbnailForChatGroup(groupId, bytes, filePath);
}

class MyAppApiImp extends MyAppApi {
  @override
  Future<NetworkResponse> getStatusChatList(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(requiredToken: false)
          .get(_MyAppEndpoint.getStatusChatList(), queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) =>
            (json as List).map((e) => PlatformStatusChat.fromJson(e)).toList(),
      );
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getMyCurrentStatusChatForPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getMyCurrentStatusChatForPlatformId(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformStatusChat.fromJson(json),
      );
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> getStatusChatForPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .get(_MyAppEndpoint.getStatusChatForPlatformId(),
              queryParameters: params);
      return NetworkResponse.fromResponse(
        response,
        converter: (json) => PlatformStatusChat.fromJson(json),
      );
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> updateStatusChatForPlatformId(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .put(_MyAppEndpoint.updateStatusChatForPlatformId(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> createChatGroup(params) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      Response response = await AppClient(
              requiredToken: true, token: await appPrefs.getNormalToken())
          .post(_MyAppEndpoint.createChatGroup(), data: params);
      return NetworkResponse.fromResponse(response,
          value: response.statusCode == 200);
    } on DioException catch (e) {
      appDebugPrint('DioException: $e');
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }

  @override
  Future<NetworkResponse> setThumbnailForChatGroup(
      groupId, bytes, filePath) async {
    bool isDisconnect = await WifiService.isDisconnectWhenCallApi();
    if (isDisconnect) return NetworkResponse.withDisconnect();
    try {
      String fileName = filePath.split('/').last;
      FormData formData = FormData.fromMap({
        "fileName": MultipartFile.fromBytes(bytes, filename: fileName),
        "groupId": groupId,
      });
      final token = await appPrefs.getNormalToken();
      Response response = await AppClient(requiredToken: true, token: token)
          .post(_MyAppEndpoint.setThumbnailForChatGroup(), data: formData);
      return NetworkResponse.fromResponse(response,
          converter: (json) => FileUploadResult.fromJson(json));
    } on DioException catch (e) {
      return NetworkResponse.withErrorRequest(e);
    } catch (e) {
      return NetworkResponse.withErrorConvert(e);
    }
  }
}
